#[repr(u8)]pub enum Pt0Bc {
PT0_BC_0 = 0,
PT0_BC_1 = 1,
PT0_BC_2 = 2,
PT0_BC_3 = 3,
}Variants
PT0_BC_0 = 0
Force the B input in this product term to a logical zero
PT0_BC_1 = 1
Pass the B input in this product term
PT0_BC_2 = 2
Complement the B input in this product term
PT0_BC_3 = 3
Force the B input in this product term to a logical one
Implementations