#[repr(u8)]pub enum Pt1Ac {
PT1_AC_0 = 0,
PT1_AC_1 = 1,
PT1_AC_2 = 2,
PT1_AC_3 = 3,
}Variants
PT1_AC_0 = 0
Force the A input in this product term to a logical zero
PT1_AC_1 = 1
Pass the A input in this product term
PT1_AC_2 = 2
Complement the A input in this product term
PT1_AC_3 = 3
Force the A input in this product term to a logical one
Implementations