#[repr(u8)]pub enum Pt1Bc {
PT1_BC_0 = 0,
PT1_BC_1 = 1,
PT1_BC_2 = 2,
PT1_BC_3 = 3,
}Variants
PT1_BC_0 = 0
Force the B input in this product term to a logical zero
PT1_BC_1 = 1
Pass the B input in this product term
PT1_BC_2 = 2
Complement the B input in this product term
PT1_BC_3 = 3
Force the B input in this product term to a logical one
Implementations