#[repr(u8)]pub enum Pt1Cc {
PT1_CC_0 = 0,
PT1_CC_1 = 1,
PT1_CC_2 = 2,
PT1_CC_3 = 3,
}Variants
PT1_CC_0 = 0
Force the C input in this product term to a logical zero
PT1_CC_1 = 1
Pass the C input in this product term
PT1_CC_2 = 2
Complement the C input in this product term
PT1_CC_3 = 3
Force the C input in this product term to a logical one
Implementations