#[repr(u8)]pub enum Pt1Dc {
PT1_DC_0 = 0,
PT1_DC_1 = 1,
PT1_DC_2 = 2,
PT1_DC_3 = 3,
}Variants
PT1_DC_0 = 0
Force the D input in this product term to a logical zero
PT1_DC_1 = 1
Pass the D input in this product term
PT1_DC_2 = 2
Complement the D input in this product term
PT1_DC_3 = 3
Force the D input in this product term to a logical one
Implementations