#[repr(u8)]pub enum Pt2Ac {
PT2_AC_0 = 0,
PT2_AC_1 = 1,
PT2_AC_2 = 2,
PT2_AC_3 = 3,
}Variants
PT2_AC_0 = 0
Force the A input in this product term to a logical zero
PT2_AC_1 = 1
Pass the A input in this product term
PT2_AC_2 = 2
Complement the A input in this product term
PT2_AC_3 = 3
Force the A input in this product term to a logical one
Implementations