#[repr(u8)]pub enum Pt2Dc {
PT2_DC_0 = 0,
PT2_DC_1 = 1,
PT2_DC_2 = 2,
PT2_DC_3 = 3,
}Variants
PT2_DC_0 = 0
Force the D input in this product term to a logical zero.
PT2_DC_1 = 1
Pass the D input in this product term.
PT2_DC_2 = 2
Complement the D input in this product term.
PT2_DC_3 = 3
Force the D input in this product term to a logical one.
Implementations